@@ -15,6 +15,7 @@ from getpass import getpass
 from distutils.version import LooseVersion
 from cravat import util
 
+
 class ExampleCommandsFormatter(object,):
     def __init__(self, prefix='',  cmd_indent=' '*2, desc_indent=' '*8, width=70):
         self._prefix = prefix
@@ -173,6 +174,8 @@ def yaml_string(x):
     return s
 
 def print_info(args):
+    if args.md is not None:
+        constants.custom_modules_dir = args.md
     module_name = args.module
     installed = False
     remote_available = False
@@ -252,6 +255,8 @@ def set_modules_dir(args):
     print(au.get_modules_dir())
 
 def install_modules(args):
+    if args.md is not None:
+        constants.custom_modules_dir = args.md
     matching_names = au.search_remote(*args.modules)
     if len(matching_names) > 1 and args.version is not None:
         sys.exit('Version filter cannot be applied to multiple modules')
@@ -282,6 +287,7 @@ def install_modules(args):
                 selected_install[module_name] = args.version
     # Add dependencies of selected modules
     dep_install = {}
+    pypi_deps_install = {}
     if not args.skip_dependencies:
         for module_name, version in selected_install.items():
             deps = au.get_install_deps(module_name, version=version)
@@ -307,15 +313,19 @@ def install_modules(args):
                     continue
         for module_name, module_version in sorted(to_install.items()):
             stage_handler = InstallProgressStdout(module_name, module_version)
-            au.install_module(module_name,
-                                version=module_version,
-                                force_data=args.force_data,
-                                stage_handler=stage_handler,
-                                force=args.force,
-                                skip_data=args.skip_data,
-                                )
+            au.install_module(
+                module_name,
+                version=module_version,
+                force_data=args.force_data,
+                stage_handler=stage_handler,
+                force=args.force,
+                skip_data=args.skip_data,
+                install_pypi_dependency=args.install_pypi_dependency
+            )
 
 def update_modules(args):
+    if args.md is not None:
+        constants.custom_modules_dir = args.md
     if len(args.modules) > 0:
         requested_modules = au.search_local(*args.modules)
     else:
@@ -350,6 +360,8 @@ def update_modules(args):
         install_modules(args)
 
 def uninstall_modules (args):
+    if args.md is not None:
+        constants.custom_modules_dir = args.md
     matching_names = au.search_local(*args.modules)
     if len(matching_names) > 0:
         print('Uninstalling: {:}'.format(', '.join(matching_names)))
@@ -369,22 +381,35 @@ def uninstall_modules (args):
         print('No modules to uninstall found')
 
 def publish_module (args):
+    if args.md is not None:
+        constants.custom_modules_dir = args.md
+    sys_conf = au.get_system_conf()
+    if args.user is None:
+        if 'publish_username' in sys_conf:
+            args.user = sys_conf['publish_username']
+        else:
+            args.user = input("Username: ")
     if args.password is None:
-        args.password = getpass()
+        if 'publish_password' in sys_conf:
+            args.password = sys_conf['publish_password']
+        else:
+            args.password = getpass()
     au.publish_module(args.module, args.user, args.password, overwrite=args.overwrite, include_data=args.data)
 
 def install_base (args):
     sys_conf = au.get_system_conf()
     base_modules = sys_conf.get(constants.base_modules_key,[])
     args = SimpleNamespace(modules=base_modules,
-                            force_data=args.force_data,
-                            version=None,
-                            yes=True,
-                            private=False,
-                            skip_dependencies=False,
-                            force=args.force,
-                            skip_data=False
-                            )
+        force_data=args.force_data,
+        version=None,
+        yes=True,
+        private=False,
+        skip_dependencies=False,
+        force=args.force,
+        skip_data=False,
+        install_pypi_dependency=args.install_pypi_dependency,
+        md=args.md
+    )
     install_modules(args)
 
 def create_account (args):
@@ -406,6 +431,8 @@ def make_example_input (arg):
     au.make_example_input(arg.directory)
 
 def new_annotator (args):
+    if args.md is not None:
+        constants.custom_modules_dir = args.md
     au.new_annotator(args.annotator_name)
     module_info = au.get_local_module_info(args.annotator_name)
     print('Annotator {0} created at {1}'.format(args.annotator_name,
@@ -465,6 +492,15 @@ parser_install_base.add_argument('-d', '--force-data',
     action='store_true',
     help='Download data even if latest data is already installed'
 )
+parser_install_base.add_argument('--install-pypi-dependency',
+    action='store_true',
+    default=True,
+    help='Try to install non-OpenCRAVAT package dependency with pip'
+)
+parser_install_base.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_install_base.set_defaults(func=install_base)
 
 # install
@@ -502,6 +538,15 @@ parser_install.add_argument('--skip-data',
     action='store_true',
     help='Skip installing data'
 )
+parser_install.add_argument('--install-pypi-dependency',
+    action='store_true',
+    default=True,
+    help='Try to install non-OpenCRAVAT package dependency with pip'
+)
+parser_install.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_install.set_defaults(func=install_modules)
 
 # update
@@ -531,6 +576,15 @@ parser_update.add_argument('--strategy',
                             type=str,
                             choices=('consensus','force','skip')
                             )
+parser_update.add_argument('--install-pypi-dependency',
+    action='store_true',
+    default=True,
+    help='Try to install non-OpenCRAVAT package dependency with pip'
+)
+parser_update.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_update.set_defaults(func=update_modules)
 
 # uninstall
@@ -542,6 +596,10 @@ parser_uninstall.add_argument('modules',
 parser_uninstall.add_argument('-y','--yes',
                                 action='store_true',
                                 help='Proceed without prompt')
+parser_uninstall.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_uninstall.set_defaults(func=uninstall_modules)
 
 # info
@@ -553,6 +611,10 @@ parser_info.add_argument('-l','--local',
                             dest='local',
                             help='Include local info',
                             action='store_true')
+parser_info.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_info.set_defaults(func=print_info)
 
 # ls
@@ -593,6 +655,10 @@ parser_ls.add_argument('--bytes',
     dest='raw_bytes',
     help='Machine readable data sizes'
     )
+parser_ls.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_ls.set_defaults(func=list_modules)
 
 # publish
@@ -612,11 +678,12 @@ data_group.add_argument('-c',
                         help='publishes module without data.')
 parser_publish.add_argument('-u',
                             '--user',
-                            required=True,
+                            default=None,
                             help='user to publish as. Typically your email.'
                             )
 parser_publish.add_argument('-p',
                             '--password',
+                            default=None,
                             help='password for the user. Enter at prompt if missing.')
 parser_publish.add_argument('--force-yes',
                             default=False,
@@ -626,6 +693,10 @@ parser_publish.add_argument('--overwrite',
                             default=False,
                             action='store_true',
                             help='overwrites a published module/version')
+parser_publish.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_publish.set_defaults(func=publish_module)
 
 # create-account
@@ -683,6 +754,10 @@ parser_new_annotator = subparsers.add_parser('new-annotator',
                                             help='creates a new annotator')
 parser_new_annotator.add_argument('annotator_name',
                                 help='Annotator name')
+parser_new_annotator.add_argument('--md',
+    default=None,
+    help='Specify the root directory of OpenCRAVAT modules'
+)
 parser_new_annotator.set_defaults(func=new_annotator)
 
 # opens issue report
