@@ -101,6 +101,7 @@ function saveFilterSetting (name, useFilterJson) {
 			success: function (response) {
 				writeLogDiv('Filter setting has been saved.');
 				resolve();
+                lastUsedFilterName = name;
 			}
 		});
 	})
@@ -487,7 +488,7 @@ function applyTableSetting (level) {
 			var colGroup = colGroups[j];
 			if (colGroup.title == colGroupSetting.title) {
 				newColModel.push(colGroup);
-				newColModel.colModel = [];
+                var newColGroupColModel = [];
 				var cols = colGroup.colModel;
 				for (k = 0; k < colGroupColsSetting.length; k++) {
 					var colSetting = colGroupColsSetting[k];
@@ -496,11 +497,12 @@ function applyTableSetting (level) {
 						if (col.col == colSetting.col) {
 							col.width = colSetting.width;
                             col.hidden = colSetting.hidden;
-							newColModel.colModel.push(col);
+							newColGroupColModel.push(col);
 							break;
 						}
 					}
 				}
+                newColModel[i].colModel = newColGroupColModel;
 			}
 		}
 	}
@@ -566,6 +568,7 @@ function loadFilterSetting (name, callback, doNotCount) {
 		$.get('/result/service/samples', {username:username, job_id:jobId, dbpath:dbPath}).done(response=>{
 			allSamples = response;
 			showFilterTabContent = true;
+            lastUsedFilterName = name;
 			setupTab('filter');
 		})
 		$.get('/result/service/loadfiltersetting', {'username': username, 'job_id': jobId, 'dbpath': dbPath, 'name': name}).done(function (response) {
@@ -582,10 +585,65 @@ function loadFilterSetting (name, callback, doNotCount) {
 	})
 }
 
+function importFilterFromFile () {
+    var sdiv = getEl('button');
+    sdiv.style.position = 'fixed';
+    sdiv.style.bottom = '0px';
+    sdiv.style.right = '0px';
+    sdiv.textContent = 'Import filter...';
+    sdiv.addEventListener('click', function (e) {
+        var input = getEl('input');
+        input.type = 'file';
+        input.addEventListener('change', function (e) {
+            var file = e.target.files[0];
+            var reader = new FileReader();
+            reader.readAsText(file, 'utf-8');
+            reader.addEventListener('load', function (e) {
+                var fs = JSON.parse(e.target.result);
+                filterMgr.updateAll(fs)
+            });
+        });
+        input.click();
+    });
+    addEl(document.body, sdiv);
+}
+
+function showImportFilterDialog () {
+    var content = getEl('div');
+    var span = getEl('span');
+    span.textContent = 'Filter file to import:\xa0';
+    addEl(content, span);
+    var input = getEl('input');
+    input.type = 'file';
+    addEl(content, input);
+    var div = document.getElementById('yesnodialog');
+    if (div != undefined) {
+        $(div).remove();
+    }
+    var div = getEl('div');
+    div.id = 'yesnodialog';
+    if (typeof content === 'string') {
+        content = getTn(content);
+    }
+    content.id = 'yesnodialog-contentdiv'
+    addEl(div, content);
+    addEl(div, getEl('br'));
+    var btnDiv = getEl('div');
+    btnDiv.className = 'buttondiv';
+    var btn = getEl('button');
+    btn.textContent = 'Cancel';
+    btn.addEventListener('click', function (evt) {
+        $('#yesnodialog').remove();
+    });
+    addEl(btnDiv, btn);
+    addEl(div, btnDiv);
+    addEl(document.body, div);
+}
+
 function getSavedFilter (name) {
 	return new Promise((resolve, reject) => {
 		$.get('/result/service/loadfiltersetting', {'username': username, 'job_id': jobId, 'dbpath': dbPath, 'name': name}).done(function (response) {
-			resolve(response['filterSet'])
+			resolve(response)
 		});
 	})
 }
